/**
 * Paytium Admin JS
 *
 * @package PT
 * @author  David de Boer <david@davdeb.com>
 */

/* global jQuery, sc_script */

(function($) {
	'use strict';

	// Set debug flag.
	var script_debug = ( (typeof sc_script != 'undefined') && sc_script.script_debug == true);

	$(function () {

		if (script_debug) {
			console.log('sc_script', sc_script);
		}

		var $body = $( document.body );

		$body.find( '.sc-license-wrap button.sc-license-action' ).on( 'click.eddLicenseActivate', function( event ) {

			event.preventDefault();

			var button = $(this);
			var licenseWrap = button.closest( '.sc-license-wrap' );
			var licenseInput = licenseWrap.find( 'input.sc-license-input' );

			if ( licenseInput.val().length < 1 ) {

				button.html( sc_strings.activate );
				button.data( 'sc-action', 'activate_license' );
				licenseWrap.find( '.sc-license-message' ).html( sc_strings.inactive_msg ).removeClass( 'sc-valid sc-invalid' ).addClass( 'sc-inactive' );

			} else {

				// WP 4.2+ wants .is-active class added/removed for spinner.
				licenseWrap.find( '.spinner' ).addClass( 'is-active' );

				var data = {
					action: 'sc_activate_license',
					license: licenseInput.val(),
					item: button.data( 'sc-item'),
					sc_action: button.data( 'sc-action' ),
					id: licenseInput.attr( 'id' )
				};

				$.post( ajaxurl, data, function(response) {

					if (script_debug) {
						console.log('EDD license check response', response);
					}

					// WP 4.2+ wants .is-active class added/removed for spinner.
					licenseWrap.find( '.spinner' ).removeClass( 'is-active' );

					if ( response == 'valid' ) {

						button.html( sc_strings.deactivate );
						button.data( 'sc-action', 'deactivate_license' );
						licenseWrap.find( '.sc-license-message' ).html( sc_strings.valid_msg ).removeClass( 'sc-inactive sc-invalid' ).addClass( 'sc-valid' );

					} else if ( response == 'deactivated' ) {

						button.html( sc_strings.activate );
						button.data( 'sc-action', 'activate_license' );
						licenseWrap.find( '.sc-license-message' ).html( sc_strings.inactive_msg ).removeClass( 'sc-valid sc-invalid' ).addClass( 'sc-inactive' );

					} else if ( response == 'invalid' ) {

						licenseWrap.find( '.sc-license-message' ).html( sc_strings.invalid_msg ).removeClass( 'sc-inactive sc-valid' ).addClass( 'sc-invalid' );

					} else if ( response == 'notfound' ) {

						licenseWrap.find( '.sc-license-message' ).html( sc_strings.notfound_msg ).removeClass( 'sc-inactive sc-valid' ).addClass( 'sc-invalid' );

					} else if ( response == 'error' ) {

						licenseWrap.find( '.sc-license-message' ).html( sc_strings.error_msg ).removeClass( 'sc-inactive sc-valid' ).addClass( 'sc-invalid' );
					}
				});
			}
		});

		// Make enter keypress from input box fires off correct activate button in the case of more than one.
		$body.find( '.sc-license-wrap input.sc-license-input').keypress( function ( event ) {

			var licenseInput = $(this);

			if ( event.keyCode == 13 ) {
				event.preventDefault();

				licenseInput.siblings( 'button.sc-license-action:first' ).click();
			}
		});

	});

    // START - Update amount in Setup Wizard > Payment test
    var $body = $( 'body' );
    var ptFormList = $body.find('.pt-checkout-form');

    ptFormList.each(function() {
        var ptForm = $(this);

        ptForm.find('.pt-payment-btn').on('click.ptPaymentBtn', function (event) {
                var finalAmount = '49.95';
                ptForm.find('.pt_amount').val(finalAmount);
        });
    });
    // END - Update amount in Setup Wizard > Payment test


    jQuery(document).ready(function ($) {
        jQuery(".paytium-cancel-subscription").bind("click", function (e) {

            jQuery(this).prop('disabled', true);
            e.preventDefault();

            var data = {
                'action': 'pt_cancel_subscription',
                'payment_id': $("#payment_id").attr('value'),
                'subscription_id': $("#subscription_id").attr('value'),
                'customer_id': $("#customer_id").attr('value')
            };

            jQuery.post(ajaxurl, data, function (response) {

                var $body = $('body');

                if (response.success == false) {
                    $body.find('.option-group-subscription-cancelled').show();
                    $body.find('.option-group-subscription-cancelled .option-value').text('Cancel failed!');
                    $body.find('.option-group-subscription-cancelled').css('color', '#ba0005');
                }

                if (response.success == true) {

                    // Remove the 'Cancel subscription' button
                    $body.find('#pt_subscription_details #major-publishing-actions').remove();

                    // Change subscription status
                    $body.find('#option-value-subscription-status').text(response.status);
                    $body.find('#option-value-subscription-status').css('color', '#0085ba');

                    // Add 'Cancelled' option row, with cancelledDateTime
                    $body.find('.option-group-subscription-cancelled').show();
                    $body.find('.option-group-subscription-cancelled .option-value').text(response.time);
                    $body.find('.option-group-subscription-cancelled .option-value').css('color', '#0085ba');
                }
            });

        });

        var loading = false;

        jQuery("body.post-type-paytium_emails .column-status").on("click", function (e) {

            if (loading == false) {
                console.log(loading);
                loading = true;
                var target = jQuery(this).children('span'),
                    data = {
                        action: 'pt_email_status_change',
                        email_id: target.data('id'),
                        email_status: target.data('status')
                    };

                target.hide();

                var loaderContainer = $( '<span/>', {
                    'class': 'loader-image-container'
                }).insertAfter( target );

                var loader = $( '<img/>', {
                    src: '/wp-admin/images/loading.gif',
                    'class': 'loader-image'
                }).appendTo( loaderContainer );

                jQuery.post( ajaxurl, data, function(response) {

                    if (response == 'success') {
                        if (data['email_status'] == 1) {
                            target.data('status', 0);
                            target.attr('data-status', 0);
                            target.removeClass('dashicons-yes').addClass('dashicons-no');
                        }
                        else {
                            target.data('status', 1);
                            target.attr('data-status', 1);
                            target.removeClass('dashicons-no').addClass('dashicons-yes');
                        }
                    }
                    else {
                        console.log('error');
                    }
                    loaderContainer.remove();
                    target.show();
                    loading = false;
                });
            }
        });

        if (jQuery('input[name="paytium_enable_live_key"]').length > 0) {

            // Always check on page load
            checkMollieApiKeysFields();

            // Also check when API key's might be entered
            jQuery('input[name="paytium_enable_live_key"], table.form-table #paytium_live_api_key, table.form-table #paytium_test_api_key').on('change keyup', function (e) {
                checkMollieApiKeysFields();
            });
        }

        function checkMollieApiKeysFields() {

            var liveApiKey = jQuery('table.form-table #paytium_live_api_key'),
                testApiKey = jQuery('table.form-table #paytium_test_api_key'),
                errorBlock = "<div class='pt-alert pt-alert-info pt-alert-settings'>"+paytium_localize_script_vars.not_entered_api_keys+"</div>";

            if (liveApiKey.val() === '' || testApiKey.val() === '') {
                if (jQuery('.pt-alert-settings').length === 0) {
                    jQuery('table.form-table').before(errorBlock);
                }
            }
            else {
                if (jQuery('.pt-alert-settings').length > 0) {
                    jQuery('.pt-alert-settings').remove();
                }
            }

            if (liveApiKey.val() !== '' && jQuery('input[name="paytium_enable_live_key"]').is(':checked')) {
                $('#paytium_admins_test_mode').parents('tr').show();
            }
            else {
                $('#paytium_admins_test_mode').parents('tr').hide();
            }

        }

        if ( jQuery('#pt_daterange_filter').length > 0 ) {

            jQuery('#pt_daterange_filter').daterangepicker({
                autoUpdateInput: false,
                ranges: {
                    'Today': [moment(), moment()],
                    'Yesterday': [moment().subtract(1, 'days'), moment().subtract(1, 'days')],
                    'Last 7 Days': [moment().subtract(6, 'days'), moment()],
                    'Last 30 Days': [moment().subtract(29, 'days'), moment()],
                    'This Month': [moment().startOf('month'), moment().endOf('month')],
                    'Last Month': [moment().subtract(1, 'month').startOf('month'), moment().subtract(1, 'month').endOf('month')],
                },
                locale: {
                    format: 'MMMM D YYYY'
                }
            }, function(start, end, label) {
                jQuery('#pt_daterange_filter').val(start.format('MMMM D YYYY')+' - '+end.format('MMMM D YYYY'));
            })
        }

        if ( jQuery('#paytium-export-invoices-date-range-start').length > 0 ) {
            jQuery('#paytium-export-invoices-date-range-start').datepicker({ dateFormat: 'dd-mm-yy' });
            jQuery('#paytium-export-invoices-date-range-end').datepicker({ dateFormat: 'dd-mm-yy' });
        }
        if ( jQuery('#paytium-export-payments-date-range-start').length > 0 ) {
            jQuery('#paytium-export-payments-date-range-start').datepicker({ dateFormat: 'dd-mm-yy' });
            jQuery('#paytium-export-payments-date-range-end').datepicker({ dateFormat: 'dd-mm-yy' });
        }

        jQuery(".paytium-notice .notice-dismiss").on("click", function (e) {

            var noticeId = $(this).parent('.paytium-notice').data('id'),
                data = {
                    id: noticeId,
                    action: 'paytium_notice_dismiss'
                };

            jQuery.post( ajaxurl, data, function(response) {

                if (response == 'success') {
                    console.log('paytium notice dismiss: success');
                }
                else console.log('paytium notice dismiss: error');
            });
        });

        $('.recent-payments tr').click( function() {
            window.location = $(this).find('a').attr('href');
        }).hover( function() {
            $(this).toggleClass('hover');
        });

        if (jQuery('.pt_email_add_attachments').length > 0) {
            if ( typeof wp !== 'undefined' && wp.media && wp.media.editor) {
                jQuery(document).on('click', '.pt_email_add_attachments', function(e) {
                    e.preventDefault();
                    var button = jQuery(this),
                        ids = button.prev(),
                        attachmentsContainer = jQuery('#email-attachments-container');
                    wp.media.editor.send.attachment = function(props, attachment) {

                        var data = {
                                action: 'paytium_emails_attachments',
                                attachment_id: attachment.id
                            },
                            attachmentHtml = '<div class="email-attachment" id="'+attachment.id+'">' +
                                '<span class="pt-remove-attachment">✕</span>';

                        jQuery.post( ajaxurl, data, function(response) {

                            if (response.result == 'success') {

                                if (response.thumbnail) {
                                    attachmentHtml += '<img src="'+response.thumbnail+'" alt="'+attachment.title+'">'
                                }
                                attachmentHtml += '<p><a href="'+attachment.url+'" target="_blank">'+attachment.filename+'</a></p></div>';

                                attachmentsContainer.append(attachmentHtml);

                                var idsVal = ids.val();
                                if (idsVal == '') {
                                    ids.val(attachment.id);
                                }
                                else {
                                    ids.val(idsVal+','+attachment.id);
                                }
                            }
                            else console.log('error');
                        });
                    };
                    wp.media.editor.open(button);
                    return false;
                });
            }
            jQuery(document).on('click','.pt-remove-attachment',function () {

                var id = $(this).parent().attr('id'),
                    ids = jQuery('#pt_email_add_attachments'),
                    idsVal = $(ids).val(),
                    idsArr = idsVal.split(',');

                idsArr.splice( $.inArray(id,idsArr) ,1 );
                $(ids).val(idsArr.toString());

                var that = this;
                $(this).parent().fadeOut('slow', function(){
                    $(that).parent().remove();
                });

            })
        }

        if ($('#export-payments-form').length > 0) {

            $('#export_payments').on('click',function(e){
                e.preventDefault();

                var data = {
                    start_date: $('#paytium-export-payments-date-range-start').val(),
                    end_date: $('#paytium-export-payments-date-range-end').val(),
                    statuses: $('#paytium_order-statuses').val(),
                    columns: $('#paytium_columns').val(),
                    sources: $('#paytium-payment-sources').val(),
                    action: 'paytium_export_payments'
                };

                jQuery.post( ajaxurl, data, function(response) {

                    if (response.result == 'conflict') {

                        $('#export_payments').hide();
                        $('.conflict').fadeIn();
                    }
                    else if (response.result == 'payments_without_source_id') {

                        $('#export_payments').hide();
                        $('.payment-source-warning').fadeIn();
                    }
                    else {
                        console.log(response.result);
                        $('#export-payments-form').submit();
                    }

                });
            });

            var source = $('.select2-selection.select2-selection--multiple').get(2);

            $('#conflict_continue_anyway, #conflict_set_payment_source').on('click',function(e){

                $('.conflict').hide();
                $('#export_payments').fadeIn();

                if ($(e.target).is('#conflict_continue_anyway')) {
                    $('#export-payments-form').submit();
                }
                else if ($(e.target).is('#conflict_set_payment_source')) {
                    $('#paytium-payment-sources').select2('open');
                    $(source).css({border: 'solid #FF9800 1px'});
                }
            });

            $('#paytium-payment-sources').on('select2:close', function () {
                $(source).attr('style','border','');
            });

            $('#payment_source_continue_with, #payment_source_continue_without').on('click',function(e){

                $('.payment-source-warning').hide();
                $('.conflict').hide();
                $('#export_payments').fadeIn();

                if ($(e.target).is('#payment_source_continue_with')) {
                    $('#export-payments-form').submit();
                }
                else if ($(e.target).is('#payment_source_continue_without')) {
                    $('#paytium-payment-sources').val('');
                    $('#export-payments-form').submit();
                }
            });

        }

    });

}(jQuery));


